class Hermes::Api::Dmo::NotificationCenter::NotificationsController < Hermes::Api::Dmo::ApplicationController
  include ::NotificationsApiCommonController
  before_action :set_notifications, only: %i[index open_all]
  before_action :set_notification, only: %i[show open move destroy]
  
  # Returns notification index of the target.
  def index
    paginate(@notifications, each_serializer: serializer)
  end

  # Opens all notifications of the target.
  def open_all
    @notifications = @notifications.to_a.map do |notif|
      notif.open!
      notif.reload
    end
    
    paginate(@notifications, each_serializer: serializer)
  end

  # Returns a single notification.
  def show
    render(jsonapi: @notification, serializer: serializer)
  end

  # Deletes a notification.
  def destroy
    @notification.destroy
    render json: {}, status: 204
  end

  # Opens a notification.
  def open
    @notification.open!
    render(jsonapi: @notification, serializer: serializer)
  end

  # Moves to notifiable_path of the notification.
  def move
    @notification.open!
    render(jsonapi: @notification, serializer: serializer, links: { notifiable_url: @notification.notifiable.notifiable_path })
  end

  protected

  def serializer
    ::Hermes::NotificationCenter::NotificationSerializer
  end
end