# frozen_string_literal: true

require 'rails_helper'

RSpec.describe CloseContractJob, type: :job do
  let!(:lessor) { create(:lessor) }
  let!(:entity) { create(:entity, lessor: lessor, siren: '123456789', siret: '12345678901234') }
  let!(:applicant) { create(:applicant, main_employer_siret: entity.siret) }
  let!(:housing_offer) { create(:housing_offer, lessor: lessor) }
  let!(:housing_entity_offer) { create(:housing_entity_offer, housing_offer: housing_offer, entity: entity) }
  let!(:housing_request) { create(:housing_request, main_applicant_id: applicant.id, lessor_siren: '123456789', is_active: true) }
  let!(:housing_application) do
    create(:housing_application, {
      housing_offer_id: housing_offer.id.to_s,
      housing_request_id: housing_request.id.to_s
    })
  end
  let!(:entity_validation) { create(:entity_validation, entity: entity, applicant: applicant) }

  
  describe 'CloseContractJob' do
    it 'should close contract and cancel applications' do
      expect(housing_application.reload.is_active).to be(true)
      expect(housing_request.reload.entity_id).not_to be_nil
      perform_enqueued_jobs do
        close_date = Date.today
        entity_validation.set(contract_end_date: close_date)
        CloseContractJob.perform_later(entity_validation.id.to_s)
        expect(housing_application.reload.is_active).to be(false)
        expect(housing_request.reload.entity_id).to be_nil
      end
    end
  end
end
